---
name: "✨ Запрос функции"
about: Предложить новую функцию или улучшение
title: ''
labels: enhancement
assignees: ''

---

## 🎯 Описание функции
Что вы хотите добавить/улучшить?

## 💡 Мотивация
Какую проблему это решит?

## 📋 Детали реализации
Как вы видите это решение?

## 🔄 Альтернативы
Рассматривали ли другие варианты?
